Index: /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMLogViewer.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMLogViewer.cpp	(revision 29380)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMLogViewer.cpp	(revision 29381)
@@ -246,15 +246,7 @@
         tr ("Save VirtualBox Log As"), defaultFullName);
 
     /* Save new log into the file */
     if (!newFileName.isEmpty())
-    {
-        /* Reread log data */
-        QFile newFile (newFileName);
-        if (!newFile.open (QIODevice::WriteOnly))
-            return;
-
-        /* Save log data into the new file */
-        newFile.write (mLogFiles.at(mLogList->currentIndex()).second->toPlainText().toUtf8());
-    }
+        QFile::copy(mMachine.QueryLogFilename(mLogList->currentIndex()), newFileName);
 }
 
@@ -246,15 +246,7 @@
         tr ("Save VirtualBox Log As"), defaultFullName);
 
-    /* Save new log into the file */
+    /* Copy log into the file */
     if (!newFileName.isEmpty())
